aboutsummaryrefslogtreecommitdiff
path: root/scumm/sound.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'scumm/sound.cpp')
-rw-r--r--scumm/sound.cpp3
1 files changed, 2 insertions, 1 deletions
diff --git a/scumm/sound.cpp b/scumm/sound.cpp
index 4cd20fe919..ea641c382f 100644
--- a/scumm/sound.cpp
+++ b/scumm/sound.cpp
@@ -225,7 +225,8 @@ void Sound::playSound(int soundID) {
return; // abort
size = READ_BE_UINT32_UNALIGNED(ptr+4);
- rate = 8000; // FIXME - what value here ?!? 8000 is just a guess
+ // FIXME - what value here ?!? 11025 is just a guess based on strings in w32 bin, prev guess 8000
+ rate = 11025;
// Allocate a sound buffer, copy the data into it, and play
sound = (char*)malloc(size);